Crate audio_samples_io

Crate audio_samples_io 

Re-exports

pub use crate::wav::StreamedWavFile;
pub use crate::wav::StreamedWavWriter;
pub use crate::wav::build_wav_header;
pub use crate::wav::wav_data_len;
pub use crate::wav::wav_file::WavFile;
pub use crate::wav::wav_file_len;
pub use crate::wav::wav_header_len;
pub use crate::streaming::StreamedAudioWriter;
pub use crate::error::AudioIOError;
pub use crate::error::AudioIOResult;
pub use crate::traits::AudioFile;
pub use crate::traits::AudioFileMetadata;
pub use crate::traits::AudioFileRead;
pub use crate::traits::AudioStreamReader;
pub use crate::types::BaseAudioInfo;
pub use crate::types::FileType;
pub use crate::types::OpenOptions;
pub use crate::types::ValidatedSampleType;
pub use crate::types::WriteOptions;

Modules

error
streaming
Format-agnostic streaming writer.
traits
types
wav

Traits

ReadSeek
Convenience trait for types that implement both Read and Seek
WriteSeek

Functions

create_streamed
Create a streaming writer to a file path, choosing WAV or FLAC from the extension.
create_streamed_sink
Create a non-seekable streaming WAV writer (WavSink) over any Write destination — stdout, a pipe, a socket, etc.
create_streamed_with
Create a streaming writer to any WriteSeek destination with an explicit format.
create_streamed_with_options
Create a streaming writer to a file path with explicit WriteOptions.
create_streamed_writer
Create a streaming WAV writer to any WriteSeek destination.
info
Get basic audio information from a file
open
Open an audio file for reading/writing operations
open_streamed
Open a WAV file for streaming reads.
open_streamed_dyn
Open an audio file for streaming reads, returning a trait object.
open_streamed_reader
Open any Read + Seek source for streaming WAV reads.
peek_native_type
Peek at the native sample type of an audio file with minimal I/O.
read
Read audio samples from a file
write
write_with
Write audio data to any Write destination with explicit format specification.
write_with_metadata
Write a WAV file with trailing metadata chunks (LIST/INFO tags, cue points).
write_with_metadata_to
Write a WAV file with trailing metadata to any Write destination (e.g. an in-memory buffer).
write_with_options
Write audio samples to a file with explicit WriteOptions.
write_with_writer_options
Write audio data to any Write destination with explicit format and WriteOptions.