AudioFileMetadata

Trait AudioFileMetadata 

pub trait AudioFileMetadata {
    // Required methods
    fn open_metadata<P: AsRef<Path>>(path: P) -> AudioIOResult<Self>
       where Self: Sized;
    fn base_info(&self) -> AudioIOResult<BaseAudioInfo>;
    fn specific_info(&self) -> impl AudioInfoMarker;
    fn file_type(&self) -> FileType;
    fn file_path(&self) -> &Path;
    fn total_samples(&self) -> usize;
    fn duration(&self) -> AudioIOResult<Duration>;
    fn sample_type(&self) -> ValidatedSampleType;
    fn num_channels(&self) -> u16;

    // Provided methods
    fn info(&self) -> AudioIOResult<AudioInfo<impl AudioInfoMarker>> { ... }
    fn samples_per_channel(&self) -> AudioIOResult<usize> { ... }
}

Required Methods

fn open_metadata<P: AsRef<Path>>(path: P) -> AudioIOResult<Self>
where Self: Sized,

Open file for metadata operations only (no sample type needed)

fn base_info(&self) -> AudioIOResult<BaseAudioInfo>

Get basic audio information from file headers

fn specific_info(&self) -> impl AudioInfoMarker

Get format-specific audio information

fn file_type(&self) -> FileType

Get the file format type

fn file_path(&self) -> &Path

Get the file path

fn total_samples(&self) -> usize

Get total number of samples in the file

fn duration(&self) -> AudioIOResult<Duration>

Get duration of the audio

fn sample_type(&self) -> ValidatedSampleType

Get the sample data type of the audio file SampleType should be validated during file opening

fn num_channels(&self) -> u16

Get the number of channels in the audio file

Provided Methods

fn info(&self) -> AudioIOResult<AudioInfo<impl AudioInfoMarker>>

Get complete audio information (base + specific)

fn samples_per_channel(&self) -> AudioIOResult<usize>

Get samples per channel

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors