Re-exports
pub use crate::wav::StreamedWavFile;pub use crate::wav::StreamedWavWriter;pub use crate::wav::build_wav_header;pub use crate::wav::wav_data_len;pub use crate::wav::wav_file::WavFile;pub use crate::wav::wav_file_len;pub use crate::wav::wav_header_len;pub use crate::streaming::StreamedAudioWriter;pub use crate::error::AudioIOError;pub use crate::error::AudioIOResult;pub use crate::traits::AudioFile;pub use crate::traits::AudioFileMetadata;pub use crate::traits::AudioFileRead;pub use crate::traits::AudioStreamReader;pub use crate::types::BaseAudioInfo;pub use crate::types::FileType;pub use crate::types::OpenOptions;pub use crate::types::ValidatedSampleType;pub use crate::types::WriteOptions;
Modules
Traits
Functions
- create_
streamed - Create a streaming writer to a file path, choosing WAV or FLAC from the extension.
- create_
streamed_ sink - Create a non-seekable streaming WAV writer (
WavSink) over anyWritedestination — stdout, a pipe, a socket, etc. - create_
streamed_ with - Create a streaming writer to any
WriteSeekdestination with an explicit format. - create_
streamed_ with_ options - Create a streaming writer to a file path with explicit
WriteOptions. - create_
streamed_ writer - Create a streaming WAV writer to any
WriteSeekdestination. - info
- Get basic audio information from a file
- open
- Open an audio file for reading/writing operations
- open_
streamed - Open a WAV file for streaming reads.
- open_
streamed_ dyn - Open an audio file for streaming reads, returning a trait object.
- open_
streamed_ reader - Open any
Read + Seeksource for streaming WAV reads. - peek_
native_ type - Peek at the native sample type of an audio file with minimal I/O.
- read
- Read audio samples from a file
- write
- write_
with - Write audio data to any
Writedestination with explicit format specification. - write_
with_ metadata - Write a WAV file with trailing metadata chunks (LIST/INFO tags, cue points).
- write_
with_ metadata_ to - Write a WAV file with trailing metadata to any
Writedestination (e.g. an in-memory buffer). - write_
with_ options - Write audio samples to a file with explicit
WriteOptions. - write_
with_ writer_ options - Write audio data to any
Writedestination with explicit format andWriteOptions.